<?php
namespace AustraliaPost\Extensions\Business\API\Wrapper\Connectors;

class My_Post_Connector extends Abstract_Connector {

	const ACCOUNT_NUMBER_OPTION_KEY = '_labelspro_mypost_account_number';
	const CHARGING_ACCOUNTS_OPTION_KEY = '_labelspro_mypost_charging_accounts';

	const API_URL = 'https://mypost-forwarder.wpruby.com/api/forward/shipping/v1';
	private $test_mode = false;

	private $merchant_token;
	private $account_number;


	/**
	 * Connector constructor.
	 *
	 * @param string $merchant_token
	 * @param string|null $account_number
	 */
	public function __construct( $merchant_token, $account_number )
	{
		$this->merchant_token = $merchant_token;
		$this->account_number = $account_number;
	}

	protected function getHeaders()
	{
		$headers = [
			'Accept'         => 'application/json',
			'Content-Type'   => 'application/json',
			'auspost-merchant-token'  => $this->merchant_token,
			'auspost-test-mode' => $this->testMode(),
		];
		if ($this->testMode() === true) {
			$headers['x-env'] = 2;
		}

		if ($this->account_number) {
			$headers['account-number'] = $this->account_number;
		}

		return $headers;
	}

	/**
	 * @return mixed
	 */
	public function getAccountNumber() {
		return $this->account_number;
	}

	/**
	 * @return mixed
	 */
	protected function testMode()
	{
		return $this->test_mode;
	}

	/**
	 * @return mixed
	 */
	protected function apiUrl()
	{
		return self::API_URL;
	}
}
